//+------------------------------------------------------------------+
//|                                                                  |
//|                                                                  |
//|                                                                  |
//+------------------------------------------------------------------+

extern string BOLLINGER_PARAMETERS      ="        ||---------------------------------Bollinger Parameters---------------------------------||";
extern double MAPeriod = 20;
extern double Deviation = 2;
extern double Bands_Shift = 0;
extern double BOL_Applied_Price = 0;
extern string CCI_PARAMETERS      ="        ||---------------------------------CCI Parameters-----------------------------------------||";
extern double CCIPeriod = 21;
extern double CCI_Applied_Price = 0;
extern string ENTRANCE_PARAMETERS      ="        ||---------------------------------Entrance Parameters---------------------------------||";
extern double CCI_Long_Thresh = 0;
extern double CCI_Short_Thresh = 0;
extern double BOL_Thresh = 0.5;
extern string EXIT_PARAMETERS      ="        ||---------------------------------Exit Parameters------------------------------------------||";
extern double CCI_Long_Exit_Thresh = 100;
extern double CCI_Short_Exit_Thresh = -100;
extern string STOPLOSS_PARAMETERS      ="        ||---------------------------------Stop-Loss Parameters--------------------------------||";
extern bool MultiplyByTen = true;
extern double TakeProfit = 50;
extern double InitialStop = 30;
extern bool UseBolStops = true;
extern double Level = 20;
extern string TRADING_PARAMETERS      ="        ||---------------------------------Trading Parameters-----------------------------------||";
extern double Shift = 1;
extern double Lots = 1;

//---- INTERNAL VARIABLES
int         timeframe;
double      point;
string      symbol;

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+

//+------------------------------------------------------------------+
//| EA INITIALIZATION FUNCTION                                       |
//+------------------------------------------------------------------+

int init()
{
   symbol=Symbol();
   timeframe=Period();
   point=Point;
   
   if(MultiplyByTen==true)
   {
      point=Point*10;
   }
   
return(0);
}

int start()
{
   int cnt, ticket, total;
   
   double BolLower=iBands(symbol,timeframe,MAPeriod,Deviation,Bands_Shift,BOL_Applied_Price,MODE_LOWER,Shift);
   double BolUpper=iBands(symbol,timeframe,MAPeriod,Deviation,Bands_Shift,BOL_Applied_Price,MODE_UPPER,Shift);
   double BolMid=iBands(symbol,timeframe,MAPeriod,Deviation,Bands_Shift,BOL_Applied_Price,MODE_MAIN,Shift);
   double BolWidth=100*(BolUpper-BolLower)/BolMid;
   double CCI=iCCI(symbol,timeframe,CCIPeriod,CCI_Applied_Price,Shift);
   double CCIPrev=iCCI(symbol,timeframe,CCIPeriod,CCI_Applied_Price,Shift+1);
   
   if(Bars<100)
   {
      Print("Bars less than 100.");
      return(0);  
   }
   if(TakeProfit<10)
   {
      Print("TakeProfit less than 10.");
      return(0);
   }


   total=OrdersTotal();
   if(total<1) 
   {
      if(AccountFreeMargin()<(1000*Lots))
      {
         Print("We have no money. Free Margin = ", AccountFreeMargin());
         return(0);  
      }
      
      // CHECK FOR BUY (LONG) ENTRANCE
      if(BolWidth>BOL_Thresh && CCI>CCI_Long_Thresh && CCI<CCI_Long_Exit_Thresh && Ask<BolLower)
      { 
         //Place the order
         ticket=OrderSend(Symbol(),OP_BUY,Lots,Ask,3,Bid-InitialStop*point,Ask+TakeProfit*point,"Bol Breakout/CCI EA",110011,0,Green);
         
         if(ticket>0)
         {
            if(OrderSelect(ticket,SELECT_BY_TICKET,MODE_TRADES)) Print("BUY order opened : ",OrderOpenPrice());
         }
         else Print("Error opening BUY order : ",GetLastError()); 
         return(0); 
      }
      
      // CHECK FOR SELL (SHORT) ENTRANCE
      if(BolWidth>BOL_Thresh && CCI<CCI_Short_Thresh && CCI>CCI_Short_Exit_Thresh && Bid>BolUpper)
      {  
         //Place the order
         ticket=OrderSend(Symbol(),OP_SELL,Lots,Bid,3,Ask+InitialStop*point,Bid-TakeProfit*point,"Bol Breakout/CCI EA",110011,0,Red);
         
         if(ticket>0)
         {
            if(OrderSelect(ticket,SELECT_BY_TICKET,MODE_TRADES)) Print("SELL order opened : ",OrderOpenPrice());
         }
         else Print("Error opening SELL order : ",GetLastError()); 
         return(0); 
      }
      return(0);
   }
  
   for(cnt=0;cnt<total;cnt++)
   {
      OrderSelect(cnt, SELECT_BY_POS, MODE_TRADES);
      if(OrderType()<=OP_SELL && OrderSymbol()==Symbol())  
      {
         if(OrderType()==OP_BUY)  
         {
            if(CCIPrev>CCI_Long_Exit_Thresh && CCI<CCI_Long_Exit_Thresh)
            {
                 OrderClose(OrderTicket(),OrderLots(),Bid,3,Violet); 
                 return(0); // exit
            }

         }
         else
         {
            if(CCIPrev<CCI_Short_Exit_Thresh && CCI>CCI_Short_Exit_Thresh)
            {
               OrderClose(OrderTicket(),OrderLots(),Ask,3,Violet); 
               return(0); // exit
            }
            
         }
      }
      
      if(UseBolStops==true)
      {
         if(OrderType()==OP_BUY)
         { 
            if(Bid>(BolMid+Level*point))
            {
               OrderModify(OrderTicket(),OrderOpenPrice(),BolMid,OrderTakeProfit(),0,Green);
            }
         }
         else
         {
            if(Ask<(BolMid-Level*point))
            {
               OrderModify(OrderTicket(),OrderOpenPrice(),BolMid,OrderTakeProfit(),0,Red);
            }  
         }
      }
      
   }
   return(0);
}

